@@ -1,11 +1,11 @@
 import time
 import board
 import busio
-from adafruit_lsm6ds import ISM330DHCT
+from adafruit_lsm6ds import ISM330DHCX
 
 i2c = busio.I2C(board.SCL, board.SDA)
 
-sensor = ISM330DHCT(i2c)
+sensor = ISM330DHCX(i2c)
 
 while True:
     print("Acceleration: X:%.2f, Y: %.2f, Z: %.2f m/s^2" % (sensor.acceleration))
