@@ -2,13 +2,13 @@ import board
 import busio
 
 # pylint:disable=no-member,unused-import
-from adafruit_lsm6ds import LSM6DS33, LSM6DSOX, ISM330DHCT, Rate
+from adafruit_lsm6ds import LSM6DS33, LSM6DSOX, ISM330DHCX, Rate
 
 i2c = busio.I2C(board.SCL, board.SDA)
 
 sensor = LSM6DS33(i2c)
 # sensor = LSM6DSOX(i2c)
-# sensor = ISM330DHCT(i2c)
+# sensor = ISM330DHCX(i2c)
 
 while True:
     sensor.accelerometer_data_rate = Rate.RATE_12_5_HZ
